#################################################################
Keithley 2281S power supply and battery simulator / characterizer
#################################################################

.. autoclass:: pymeasure.instruments.keithley.Keithley2281S
    :members:
    :show-inheritance:
    :inherited-members: CommonBase

.. autoclass:: pymeasure.instruments.keithley.keithley2281S.Keithley2281SOperationEventRegister
    :members:

.. autoclass:: pymeasure.instruments.keithley.keithley2281S.Keithley2281SMeasurementEventRegister
    :members:
